@@ -10,10 +10,10 @@ import warnings
 from pyproj._crs import Datum, Ellipsoid, PrimeMeridian
 from pyproj.crs.coordinate_operation import (
     AlbersEqualAreaConversion,
-    AzumuthalEquidistantConversion,
+    AzimuthalEquidistantConversion,
     GeostationarySatelliteConversion,
     HotineObliqueMercatorBConversion,
-    LambertAzumuthalEqualAreaConversion,
+    LambertAzimuthalEqualAreaConversion,
     LambertConformalConic1SPConversion,
     LambertConformalConic2SPConversion,
     LambertCylindricalEqualAreaConversion,
@@ -23,7 +23,7 @@ from pyproj.crs.coordinate_operation import (
     OrthographicConversion,
     PolarStereographicAConversion,
     PolarStereographicBConversion,
-    RotatedLatitudeLongitudeConversion,
+    PoleRotationNetCDFCFConversion,
     SinusoidalConversion,
     StereographicConversion,
     TransverseMercatorConversion,
@@ -117,7 +117,7 @@ def _azimuthal_equidistant(cf_params):
     """
     http://cfconventions.org/cf-conventions/cf-conventions.html#azimuthal-equidistant
     """
-    return AzumuthalEquidistantConversion(
+    return AzimuthalEquidistantConversion(
         latitude_natural_origin=cf_params.get("latitude_of_projection_origin", 0.0),
         longitude_natural_origin=cf_params.get("longitude_of_projection_origin", 0.0),
         false_easting=cf_params.get("false_easting", 0.0),
@@ -147,7 +147,7 @@ def _lambert_azimuthal_equal_area(cf_params):
     """
     http://cfconventions.org/cf-conventions/cf-conventions.html#lambert-azimuthal-equal-area
     """
-    return LambertAzumuthalEqualAreaConversion(
+    return LambertAzimuthalEqualAreaConversion(
         latitude_natural_origin=cf_params.get("latitude_of_projection_origin", 0.0),
         longitude_natural_origin=cf_params.get("longitude_of_projection_origin", 0.0),
         false_easting=cf_params.get("false_easting", 0.0),
@@ -333,10 +333,10 @@ def _rotated_latitude_longitude(cf_params):
     """
     http://cfconventions.org/cf-conventions/cf-conventions.html#_rotated_pole
     """
-    return RotatedLatitudeLongitudeConversion(
-        o_lat_p=cf_params["grid_north_pole_latitude"],
-        o_lon_p=cf_params["grid_north_pole_longitude"],
-        lon_0=cf_params.get("north_pole_grid_longitude", 0.0),
+    return PoleRotationNetCDFCFConversion(
+        grid_north_pole_latitude=cf_params["grid_north_pole_latitude"],
+        grid_north_pole_longitude=cf_params["grid_north_pole_longitude"],
+        north_pole_grid_longitude=cf_params.get("north_pole_grid_longitude", 0.0),
     )
 
 
@@ -414,7 +414,7 @@ def _geostationary__to_cf(conversion):
         "grid_mapping_name": "geostationary",
         "sweep_angle_axis": sweep_angle_axis,
         "perspective_point_height": params["satellite_height"],
-        # geostationary satellites orbit arount equator
+        # geostationary satellites orbit around equator
         # so latitude_of_natural_origin is often left off and assumed to be 0.0
         "latitude_of_projection_origin": params.get("latitude_of_natural_origin", 0.0),
         "longitude_of_projection_origin": params["longitude_of_natural_origin"],
@@ -625,8 +625,30 @@ def _rotated_latitude_longitude__to_cf(conversion):
     return {
         "grid_mapping_name": "rotated_latitude_longitude",
         "grid_north_pole_latitude": params["o_lat_p"],
-        "grid_north_pole_longitude": params["o_lon_p"],
-        "north_pole_grid_longitude": params["lon_0"],
+        # https://github.com/pyproj4/pyproj/issues/927
+        "grid_north_pole_longitude": params["lon_0"] - 180,
+        "north_pole_grid_longitude": params["o_lon_p"],
+    }
+
+
+def _pole_rotation_netcdf__to_cf(conversion):
+    """
+    http://cfconventions.org/cf-conventions/cf-conventions.html#_rotated_pole
+
+    https://github.com/OSGeo/PROJ/pull/2835
+    """
+    params = _to_dict(conversion)
+    return {
+        "grid_mapping_name": "rotated_latitude_longitude",
+        "grid_north_pole_latitude": params[
+            "grid_north_pole_latitude_(netcdf_cf_convention)"
+        ],
+        "grid_north_pole_longitude": params[
+            "grid_north_pole_longitude_(netcdf_cf_convention)"
+        ],
+        "north_pole_grid_longitude": params[
+            "north_pole_grid_longitude_(netcdf_cf_convention)"
+        ],
     }
 
 
@@ -656,4 +678,5 @@ _INVERSE_GEOGRAPHIC_GRID_MAPPING_NAME_MAP = {
     "proj ob_tran o_proj=lonlat": _rotated_latitude_longitude__to_cf,
     "proj ob_tran o_proj=latlon": _rotated_latitude_longitude__to_cf,
     "proj ob_tran o_proj=latlong": _rotated_latitude_longitude__to_cf,
+    "pole rotation (netcdf cf convention)": _pole_rotation_netcdf__to_cf,
 }
