@@ -15,7 +15,7 @@ from array import array
 from dataclasses import dataclass
 from itertools import chain, islice
 from pathlib import Path
-from typing import Any, Iterable, Iterator, List, Optional, Tuple, Union, overload
+from typing import Any, Dict, Iterable, Iterator, List, Optional, Tuple, Union, overload
 
 from pyproj import CRS
 from pyproj._compat import cstrencode
@@ -73,10 +73,14 @@ class TransformerUnsafe(TransformerMaker):
 
 
 @dataclass(frozen=True)
-class TransformerFromCRS(TransformerMaker):
+class TransformerFromCRS(  # pylint: disable=too-many-instance-attributes
+    TransformerMaker
+):
     """
     .. versionadded:: 3.1.0
 
+    .. versionadded:: 3.4.0 force_over
+
     Generates a Cython _Transformer class from input CRS data.
     """
 
@@ -87,6 +91,7 @@ class TransformerFromCRS(TransformerMaker):
     authority: Optional[str]
     accuracy: Optional[str]
     allow_ballpark: Optional[bool]
+    force_over: bool = False
 
     def __call__(self) -> _Transformer:
         """
@@ -102,6 +107,7 @@ class TransformerFromCRS(TransformerMaker):
             authority=self.authority,
             accuracy=self.accuracy,
             allow_ballpark=self.allow_ballpark,
+            force_over=self.force_over,
         )
 
 
@@ -147,14 +153,16 @@ class TransformerGroup(_TransformerGroup):
         self,
         crs_from: Any,
         crs_to: Any,
-        skip_equivalent: bool = False,
         always_xy: bool = False,
         area_of_interest: Optional[AreaOfInterest] = None,
+        authority: Optional[str] = None,
+        accuracy: Optional[float] = None,
+        allow_ballpark: bool = True,
     ) -> None:
         """Get all possible transformations from a :obj:`pyproj.crs.CRS`
         or input used to create one.
 
-        .. deprecated:: 3.1 skip_equivalent
+        .. versionadded:: 3.4.0 authority, accuracy, allow_ballpark
 
         Parameters
         ----------
@@ -162,30 +170,38 @@ class TransformerGroup(_TransformerGroup):
             Projection of input data.
         crs_to: pyproj.crs.CRS or input used to create one
             Projection of output data.
-        skip_equivalent: bool, default=False
-            DEPRECATED: If true, will skip the transformation operation
-            if input and output projections are equivalent.
         always_xy: bool, default=False
             If true, the transform method will accept as input and return as output
             coordinates using the traditional GIS order, that is longitude, latitude
             for geographic CRS and easting, northing for most projected CRS.
-        area_of_interest: :class:`pyproj.transformer.AreaOfInterest`, optional
+        area_of_interest: :class:`.AreaOfInterest`, optional
             The area of interest to help order the transformations based on the
             best operation for the area.
+        authority: str, optional
+            When not specified, coordinate operations from any authority will be
+            searched, with the restrictions set in the
+            authority_to_authority_preference database table related to the
+            authority of the source/target CRS themselves. If authority is set
+            to “any”, then coordinate operations from any authority will be
+            searched. If authority is a non-empty string different from "any",
+            then coordinate operations will be searched only in that authority
+            namespace (e.g. EPSG).
+        accuracy: float, optional
+            The minimum desired accuracy (in metres) of the candidate
+            coordinate operations.
+        allow_ballpark: bool, default=True
+            Set to False to disallow the use of Ballpark transformation
+            in the candidate coordinate operations. Default is to allow.
 
         """
-        if skip_equivalent:
-            warnings.warn(
-                "skip_equivalent is deprecated.",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-
         super().__init__(
             CRS.from_user_input(crs_from)._crs,
             CRS.from_user_input(crs_to)._crs,
             always_xy=always_xy,
             area_of_interest=area_of_interest,
+            authority=authority,
+            accuracy=-1 if accuracy is None else accuracy,
+            allow_ballpark=allow_ballpark,
         )
         for iii, transformer in enumerate(self._transformers):
             # pylint: disable=unsupported-assignment-operation
@@ -303,13 +319,21 @@ class Transformer:
             ProjError.clear()
             raise ProjError(
                 "Transformer must be initialized using: "
-                "'from_crs', 'from_pipeline', or 'from_proj'."
+                "'from_crs' or 'from_pipeline'."
             )
 
         self._local = TransformerLocal()
         self._local.transformer = transformer_maker()
         self._transformer_maker = transformer_maker
 
+    def __getstate__(self) -> Dict[str, Any]:
+        return {"_transformer_maker": self._transformer_maker}
+
+    def __setstate__(self, state: Dict[str, Any]):
+        self.__dict__.update(state)
+        self._local = TransformerLocal()
+        self._local.transformer = self._transformer_maker()
+
     @property
     def _transformer(self):
         """
@@ -406,11 +430,30 @@ class Transformer:
         """
         return self._transformer.operations
 
+    def get_last_used_operation(self) -> "Transformer":
+        """
+        .. versionadded:: 3.4.0
+
+        .. note:: Requires PROJ 9.1+
+
+        See: :c:func:`proj_trans_get_last_used_operation`
+
+        Returns
+        -------
+        Transformer:
+            The operation used in the transform call.
+        """
+        return Transformer(
+            TransformerUnsafe(self._transformer.get_last_used_operation())
+        )
+
     @property
     def is_network_enabled(self) -> bool:
         """
         .. versionadded:: 3.0.0
 
+        Returns
+        -------
         bool:
             If the network is enabled.
         """
@@ -452,16 +495,15 @@ class Transformer:
     def from_proj(
         proj_from: Any,
         proj_to: Any,
-        skip_equivalent: bool = False,
         always_xy: bool = False,
         area_of_interest: Optional[AreaOfInterest] = None,
     ) -> "Transformer":
         """Make a Transformer from a :obj:`pyproj.Proj` or input used to create one.
 
-        .. versionadded:: 2.1.2 skip_equivalent
+        .. deprecated:: 3.4.1 :meth:`~Transformer.from_crs` is preferred.
+
         .. versionadded:: 2.2.0 always_xy
         .. versionadded:: 2.3.0 area_of_interest
-        .. deprecated:: 3.1 skip_equivalent
 
         Parameters
         ----------
@@ -469,14 +511,11 @@ class Transformer:
             Projection of input data.
         proj_to: :obj:`pyproj.Proj` or input used to create one
             Projection of output data.
-        skip_equivalent: bool, default=False
-            DEPRECATED: If true, will skip the transformation operation
-            if input and output projections are equivalent.
         always_xy: bool, default=False
             If true, the transform method will accept as input and return as output
             coordinates using the traditional GIS order, that is longitude, latitude
             for geographic CRS and easting, northing for most projected CRS.
-        area_of_interest: :class:`pyproj.transformer.AreaOfInterest`, optional
+        area_of_interest: :class:`.AreaOfInterest`, optional
             The area of interest to help select the transformation.
 
         Returns
@@ -495,7 +534,6 @@ class Transformer:
         return Transformer.from_crs(
             proj_from.crs,
             proj_to.crs,
-            skip_equivalent=skip_equivalent,
             always_xy=always_xy,
             area_of_interest=area_of_interest,
         )
@@ -504,20 +542,24 @@ class Transformer:
     def from_crs(
         crs_from: Any,
         crs_to: Any,
-        skip_equivalent: bool = False,
         always_xy: bool = False,
         area_of_interest: Optional[AreaOfInterest] = None,
         authority: Optional[str] = None,
         accuracy: Optional[float] = None,
         allow_ballpark: Optional[bool] = None,
+        force_over: bool = False,
     ) -> "Transformer":
         """Make a Transformer from a :obj:`pyproj.crs.CRS` or input used to create one.
 
-        .. versionadded:: 2.1.2 skip_equivalent
+        See:
+
+        - :c:func:`proj_create_crs_to_crs`
+        - :c:func:`proj_create_crs_to_crs_from_pj`
+
         .. versionadded:: 2.2.0 always_xy
         .. versionadded:: 2.3.0 area_of_interest
         .. versionadded:: 3.1.0 authority, accuracy, allow_ballpark
-        .. deprecated:: 3.1 skip_equivalent
+        .. versionadded:: 3.4.0 force_over
 
         Parameters
         ----------
@@ -525,14 +567,11 @@ class Transformer:
             Projection of input data.
         crs_to: pyproj.crs.CRS or input used to create one
             Projection of output data.
-        skip_equivalent: bool, default=False
-            DEPRECATED: If true, will skip the transformation operation
-            if input and output projections are equivalent.
         always_xy: bool, default=False
             If true, the transform method will accept as input and return as output
             coordinates using the traditional GIS order, that is longitude, latitude
             for geographic CRS and easting, northing for most projected CRS.
-        area_of_interest: :class:`pyproj.transformer.AreaOfInterest`, optional
+        area_of_interest: :class:`.AreaOfInterest`, optional
             The area of interest to help select the transformation.
         authority: str, optional
             When not specified, coordinate operations from any authority will be
@@ -549,19 +588,15 @@ class Transformer:
         allow_ballpark: bool, optional
             Set to False to disallow the use of Ballpark transformation
             in the candidate coordinate operations. Default is to allow.
+        force_over: bool, default=False
+            If True, it will to force the +over flag on the transformation.
+            Requires PROJ 9+.
 
         Returns
         -------
         Transformer
 
         """
-        if skip_equivalent:
-            warnings.warn(
-                "skip_equivalent is deprecated.",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-
         return Transformer(
             TransformerFromCRS(
                 cstrencode(CRS.from_user_input(crs_from).srs),
@@ -571,6 +606,7 @@ class Transformer:
                 authority=authority,
                 accuracy=accuracy if accuracy is None else str(accuracy),
                 allow_ballpark=allow_ballpark,
+                force_over=force_over,
             )
         )
 
@@ -580,7 +616,12 @@ class Transformer:
 
         :ref:`pipeline`
 
-        .. versionadded:: 3.1.0 AUTH:CODE string suppor (e.g. EPSG:1671)
+        See:
+
+        - :c:func:`proj_create`
+        - :c:func:`proj_create_from_database`
+
+        .. versionadded:: 3.1.0 AUTH:CODE string support (e.g. EPSG:1671)
 
         Allowed input:
           - a PROJ string
@@ -660,19 +701,34 @@ class Transformer:
         """
         Transform points between two coordinate systems.
 
+        See: :c:func:`proj_trans_generic`
+
         .. versionadded:: 2.1.1 errcheck
         .. versionadded:: 2.2.0 direction
         .. versionadded:: 3.2.0 inplace
 
+        Accepted numeric scalar or array:
+
+        - :class:`int`
+        - :class:`float`
+        - :class:`numpy.floating`
+        - :class:`numpy.integer`
+        - :class:`list`
+        - :class:`tuple`
+        - :class:`array.array`
+        - :class:`numpy.ndarray`
+        - :class:`xarray.DataArray`
+        - :class:`pandas.Series`
+
         Parameters
         ----------
-        xx: scalar or array (numpy or python)
+        xx: scalar or array
             Input x coordinate(s).
-        yy: scalar or array (numpy or python)
+        yy: scalar or array
             Input y coordinate(s).
-        zz: scalar or array (numpy or python), optional
+        zz: scalar or array, optional
             Input z coordinate(s).
-        tt: scalar or array (numpy or python), optional
+        tt: scalar or array, optional
             Input time coordinate(s).
         radians: bool, default=False
             If True, will expect input data to be in radians and will return radians
@@ -694,7 +750,7 @@ class Transformer:
         --------
 
         >>> from pyproj import Transformer
-        >>> transformer = Transformer.from_crs("epsg:4326", "epsg:3857")
+        >>> transformer = Transformer.from_crs("EPSG:4326", "EPSG:3857")
         >>> x3, y3 = transformer.transform(33, 98)
         >>> f"{x3:.3f}  {y3:.3f}"
         '10909310.098  3895303.963'
@@ -727,7 +783,7 @@ class Transformer:
         >>> xpjr, ypjr, zpjr = transprojr.transform(xpj, ypj, zpj, radians=True)
         >>> f"{xpjr:.3f} {ypjr:.3f} {zpjr:.3f}"
         '-2704026.010 -4253051.810 3895878.820'
-        >>> transformer = Transformer.from_proj("epsg:4326", 4326)
+        >>> transformer = Transformer.from_crs("EPSG:4326", 4326)
         >>> xeq, yeq = transformer.transform(33, 98)
         >>> f"{xeq:.0f}  {yeq:.0f}"
         '33  98'
@@ -776,6 +832,8 @@ class Transformer:
         """
         Iterator/generator version of the function pyproj.Transformer.transform.
 
+        See: :c:func:`proj_trans_generic`
+
         .. versionadded:: 2.1.1 errcheck
         .. versionadded:: 2.2.0 direction
 
@@ -841,7 +899,7 @@ class Transformer:
         ... ):
         ...     '{:.3f} {:.3f} {:.3f}'.format(*pt)
         '-2704214.394 -4254414.478 3894270.731'
-        >>> transproj_eq = Transformer.from_proj(
+        >>> transproj_eq = Transformer.from_crs(
         ...     'EPSG:4326',
         ...     '+proj=longlat +datum=WGS84 +no_defs +type=crs',
         ...     always_xy=True,
@@ -905,6 +963,8 @@ class Transformer:
         """
         .. versionadded:: 3.1.0
 
+        See: :c:func:`proj_trans_bounds`
+
         Transform boundary densifying the edges to account for nonlinear
         transformations along these edges and extracting the outermost bounds.
 
@@ -1100,17 +1160,14 @@ def transform(  # pylint: disable=invalid-name
     p2: Any,
     x: Any,
     y: Any,
-    z: Any = None,
-    tt: Any = None,
+    z: Optional[Any] = None,
+    tt: Optional[Any] = None,
     radians: bool = False,
     errcheck: bool = False,
-    skip_equivalent: bool = False,
     always_xy: bool = False,
 ):
     """
-    .. versionadded:: 2.1.2 skip_equivalent
     .. versionadded:: 2.2.0 always_xy
-    .. deprecated::3.1 skip_equivalent
 
     .. deprecated:: 2.6.1
         This function is deprecated. See: :ref:`upgrade_transformer`
@@ -1188,12 +1245,12 @@ def transform(  # pylint: disable=invalid-name
             "See: https://pyproj4.github.io/pyproj/stable/"
             "gotchas.html#upgrading-to-pyproj-2-from-pyproj-1"
         ),
-        DeprecationWarning,
+        FutureWarning,
         stacklevel=2,
     )
-    return Transformer.from_proj(
-        p1, p2, skip_equivalent=skip_equivalent, always_xy=always_xy
-    ).transform(xx=x, yy=y, zz=z, tt=tt, radians=radians, errcheck=errcheck)
+    return Transformer.from_proj(p1, p2, always_xy=always_xy).transform(
+        xx=x, yy=y, zz=z, tt=tt, radians=radians, errcheck=errcheck
+    )
 
 
 def itransform(  # pylint: disable=invalid-name
@@ -1204,13 +1261,10 @@ def itransform(  # pylint: disable=invalid-name
     time_3rd: bool = False,
     radians: bool = False,
     errcheck: bool = False,
-    skip_equivalent: bool = False,
     always_xy: bool = False,
 ):
     """
-    .. versionadded:: 2.1.2 skip_equivalent
     .. versionadded:: 2.2.0 always_xy
-    .. deprecated::3.1 skip_equivalent
 
     .. deprecated:: 2.6.1
         This function is deprecated. See: :ref:`upgrade_transformer`
@@ -1272,11 +1326,9 @@ def itransform(  # pylint: disable=invalid-name
             "See: https://pyproj4.github.io/pyproj/stable/"
             "gotchas.html#upgrading-to-pyproj-2-from-pyproj-1"
         ),
-        DeprecationWarning,
+        FutureWarning,
         stacklevel=2,
     )
-    return Transformer.from_proj(
-        p1, p2, skip_equivalent=skip_equivalent, always_xy=always_xy
-    ).itransform(
+    return Transformer.from_proj(p1, p2, always_xy=always_xy).itransform(
         points, switch=switch, time_3rd=time_3rd, radians=radians, errcheck=errcheck
     )
