@@ -100,7 +100,7 @@ def _copytobuffer(xxx: Any, inplace: bool = False) -> Tuple[Any, DataType]:
         A scalar, list, tuple, numpy.array,
         pandas.Series, xaray.DataArray, or dask.array.Array.
     inplace: bool, default=False
-        If True, will return the array withour a copy if it
+        If True, will return the array without a copy if it
         meets the requirements of the Python Buffer API & PROJ C-API.
 
     Returns
@@ -109,7 +109,14 @@ def _copytobuffer(xxx: Any, inplace: bool = False) -> Tuple[Any, DataType]:
         The copy of the data prepared for the PROJ API & Python Buffer API.
     """
     # check for pandas.Series, xarray.DataArray or dask.array.Array
-    if hasattr(xxx, "__array__") and callable(xxx.__array__):
+    # also handle numpy masked Arrays; note that pandas.Series also has a
+    # "mask" attribute, hence checking for simply the "mask" attr in that
+    # case isn't sufficient
+    if (
+        not hasattr(xxx, "hardmask")
+        and hasattr(xxx, "__array__")
+        and callable(xxx.__array__)
+    ):
         xxx = xxx.__array__()
 
     # handle numpy data
