@@ -1,6 +1,7 @@
 import concurrent.futures
 import json
 import platform
+from unittest.mock import patch
 
 import numpy
 import pytest
@@ -19,7 +20,13 @@ from pyproj.crs.enums import CoordinateOperationType, DatumType
 from pyproj.enums import ProjVersion, WktVersion
 from pyproj.exceptions import CRSError
 from pyproj.transformer import TransformerGroup
-from test.conftest import PROJ_GTE_82, RGF93toWSG84, assert_can_pickle, grids_available
+from test.conftest import (
+    PROJ_GTE_91,
+    PROJ_GTE_901,
+    PROJ_GTE_911,
+    assert_can_pickle,
+    grids_available,
+)
 
 
 class CustomCRS(object):
@@ -68,6 +75,15 @@ def test_from_epsg_string():
         assert CRS.from_string("epsg:xyz")
 
 
+def test_from_epsg_int_like_string():
+    proj = CRS.from_string("4326")
+    assert proj.to_epsg() == 4326
+
+    # Test with invalid EPSG code
+    with pytest.raises(CRSError):
+        assert CRS.from_string("0")
+
+
 def test_from_string():
     wgs84_crs = CRS.from_string("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs")
     with pytest.warns(UserWarning):
@@ -83,6 +99,17 @@ def test_from_string():
         )
 
 
+def test_from_numpy():
+    crs_numpy = numpy.array([4326])[0]
+    proj = CRS.from_user_input(crs_numpy)
+    assert proj.to_epsg() == 4326
+
+    # Test with invalid EPSG code
+    with pytest.raises(CRSError):
+        crs_numpy = numpy.array([0])[0]
+        assert CRS.from_epsg(crs_numpy)
+
+
 def test_from_string__invalid():
     with pytest.raises(CRSError, match="CRS input is not a string"):
         CRS.from_string(4326)
@@ -256,6 +283,9 @@ def test_repr_epsg():
 
 
 def test_repr__undefined():
+    datum_name = "unknown"
+    if PROJ_GTE_901:
+        datum_name = f"{datum_name} using nadgrids=@null"
     assert repr(
         CRS(
             "+proj=merc +a=6378137.0 +b=6378137.0 +nadgrids=@null"
@@ -272,7 +302,7 @@ def test_repr__undefined():
         "Coordinate Operation:\n"
         "- name: unknown to WGS84\n"
         "- method: NTv2\n"
-        "Datum: unknown\n"
+        f"Datum: {datum_name}\n"
         "- Ellipsoid: unknown\n"
         "- Prime Meridian: Greenwich\n"
         "Source CRS: unknown\n"
@@ -342,7 +372,10 @@ def test_datum_unknown():
         "+k=1 +x_0=0 +y_0=0 +gamma=0 +ellps=WGS84 "
         "+towgs84=0,0,0,0,0,0,0 +units=m +no_defs"
     )
-    assert crs.datum.name == "Unknown based on WGS84 ellipsoid"
+    datum_name = "Unknown based on WGS84 ellipsoid"
+    if PROJ_GTE_901:
+        datum_name = f"{datum_name} using towgs84=0,0,0,0,0,0,0"
+    assert crs.datum.name == datum_name
 
 
 def test_epsg__not_found():
@@ -367,7 +400,7 @@ def test_crs_OSR_equivalence():
     with pytest.warns(FutureWarning):
         crs3 = CRS({"init": "EPSG:4326"})
     assert crs1 == crs2
-    # these are not equivalent in proj.4 now as one uses degrees and the othe radians
+    # these are not equivalent in proj.4 now as one uses degrees and the other radians
     assert crs1 == crs3
 
 
@@ -577,14 +610,22 @@ def test_coordinate_operation_grids__alternative_grid_name():
     assert grid.direct_download is True
     assert grid.open_license is True
     assert grid.short_name == "ca_nrc_ntv1_can.tif"
-    if grids_available(grid.short_name):
+    assert grid.package_name == ""
+    assert grid.url == "https://cdn.proj.org/ca_nrc_ntv1_can.tif"
+    if (PROJ_GTE_91 and grids_available(grid.short_name, check_network=False)) or (
+        not PROJ_GTE_91 and grids_available(grid.short_name)
+    ):
         assert grid.available is True
         assert grid.full_name.endswith(grid.short_name)
+    elif PROJ_GTE_911 and pyproj.network.is_network_enabled():
+        assert grid.available is True
+        assert grid.full_name == grid.url
+    elif PROJ_GTE_91 and pyproj.network.is_network_enabled():
+        assert grid.available is True
+        assert grid.full_name == ""
     else:
         assert grid.available is False
         assert grid.full_name == ""
-    assert grid.package_name == ""
-    assert grid.url == "https://cdn.proj.org/ca_nrc_ntv1_can.tif"
 
 
 def test_coordinate_operation__missing():
@@ -612,7 +653,7 @@ def test_coordinate_operation__from_authority():
         "urn:ogc:def:coordinateOperation:EPSG::1671",
         CoordinateOperation.from_epsg(1671),
         CoordinateOperation.from_epsg(1671).to_json_dict(),
-        RGF93toWSG84,
+        "RGF93 v1 to WGS 84 (1)",
     ],
 )
 def test_coordinate_operation__from_user_input(user_input):
@@ -637,31 +678,18 @@ def test_coordinate_operation__from_authority__empty():
 
 
 def test_datum__from_epsg():
-    if PROJ_GTE_82:
-        datum_wkt = (
-            'ENSEMBLE["World Geodetic System 1984 ensemble",'
-            'MEMBER["World Geodetic System 1984 (Transit)",ID["EPSG",1166]],'
-            'MEMBER["World Geodetic System 1984 (G730)",ID["EPSG",1152]],'
-            'MEMBER["World Geodetic System 1984 (G873)",ID["EPSG",1153]],'
-            'MEMBER["World Geodetic System 1984 (G1150)",ID["EPSG",1154]],'
-            'MEMBER["World Geodetic System 1984 (G1674)",ID["EPSG",1155]],'
-            'MEMBER["World Geodetic System 1984 (G1762)",ID["EPSG",1156]],'
-            'MEMBER["World Geodetic System 1984 (G2139)",ID["EPSG",1309]],'
-            'ELLIPSOID["WGS 84",6378137,298.257223563,LENGTHUNIT["metre",1],'
-            'ID["EPSG",7030]],ENSEMBLEACCURACY[2.0],ID["EPSG",6326]]'
-        )
-    else:
-        datum_wkt = (
-            'ENSEMBLE["World Geodetic System 1984 ensemble",'
-            'MEMBER["World Geodetic System 1984 (Transit)",ID["EPSG",1166]],'
-            'MEMBER["World Geodetic System 1984 (G730)",ID["EPSG",1152]],'
-            'MEMBER["World Geodetic System 1984 (G873)",ID["EPSG",1153]],'
-            'MEMBER["World Geodetic System 1984 (G1150)",ID["EPSG",1154]],'
-            'MEMBER["World Geodetic System 1984 (G1674)",ID["EPSG",1155]],'
-            'MEMBER["World Geodetic System 1984 (G1762)",ID["EPSG",1156]],'
-            'ELLIPSOID["WGS 84",6378137,298.257223563,LENGTHUNIT["metre",1],'
-            'ID["EPSG",7030]],ENSEMBLEACCURACY[2.0],ID["EPSG",6326]]'
-        )
+    datum_wkt = (
+        'ENSEMBLE["World Geodetic System 1984 ensemble",'
+        'MEMBER["World Geodetic System 1984 (Transit)",ID["EPSG",1166]],'
+        'MEMBER["World Geodetic System 1984 (G730)",ID["EPSG",1152]],'
+        'MEMBER["World Geodetic System 1984 (G873)",ID["EPSG",1153]],'
+        'MEMBER["World Geodetic System 1984 (G1150)",ID["EPSG",1154]],'
+        'MEMBER["World Geodetic System 1984 (G1674)",ID["EPSG",1155]],'
+        'MEMBER["World Geodetic System 1984 (G1762)",ID["EPSG",1156]],'
+        'MEMBER["World Geodetic System 1984 (G2139)",ID["EPSG",1309]],'
+        'ELLIPSOID["WGS 84",6378137,298.257223563,LENGTHUNIT["metre",1],'
+        'ID["EPSG",7030]],ENSEMBLEACCURACY[2.0],ID["EPSG",6326]]'
+    )
     assert Datum.from_epsg("6326").to_wkt() == datum_wkt
 
 
@@ -889,6 +917,50 @@ def test_to_wkt_enum__invalid():
         crs.to_wkt("WKT_INVALID")
 
 
+@pytest.mark.parametrize(
+    "wkt_version",
+    ["WKT2_2015", "WKT2_2015_SIMPLIFIED", "WKT1_GDAL", "WKT1_ESRI"],
+)
+def test_to_wkt_none_warning(wkt_version):
+    wkt_string = (
+        'PROJCRS["unknown",BASEGEOGCRS["unknown",DATUM["unknown",'
+        'ELLIPSOID["WGS 84",6378137,298.257223563,LENGTHUNIT["metre",1,'
+        'ID["EPSG",9001]]]],PRIMEM["Greenwich",0,ANGLEUNIT["degree",0.0174532925199],'
+        'ID["EPSG",8901]]],CONVERSION["unknown",METHOD["Equidistant Cylindrical",'
+        'ID["EPSG",1028]],PARAMETER["Latitude of 1st standard parallel",0,'
+        'ANGLEUNIT["degree",0.0174532925199433],ID["EPSG",8823]],'
+        'PARAMETER["Longitude of natural origin",0,ANGLEUNIT["degree",0.0174532925199],'
+        'ID["EPSG",8802]],PARAMETER["False easting",0,'
+        'LENGTHUNIT["unknown",111319.490793274],ID["EPSG",8806]],'
+        'PARAMETER["False northing",0,LENGTHUNIT["unknown",111319.490793274],'
+        'ID["EPSG",8807]]],CS[Cartesian,3],AXIS["(E)",east,ORDER[1],'
+        'LENGTHUNIT["unknown",111319.490793274]],AXIS["(N)",north,ORDER[2],'
+        'LENGTHUNIT["unknown",111319.490793274]],AXIS["ellipsoidal height (h)",up,'
+        'ORDER[3],LENGTHUNIT["metre",1,ID["EPSG",9001]]]]'
+    )
+    crs = CRS.from_wkt(wkt_string)
+    with pytest.warns(FutureWarning, match="CRS cannot be converted to a WKT string"):
+        assert crs.to_wkt(version=wkt_version) is None
+
+
+def test_to_proj4_none_warning():
+    crs = CRS("EPSG:4326")
+    with patch("pyproj.crs.crs.CRS._crs") as crs_mock, pytest.warns(
+        FutureWarning, match="CRS cannot be converted to a PROJ string"
+    ):
+        crs_mock.to_proj4.return_value = None
+        assert crs.to_proj4() is None
+
+
+def test_to_json_none_warning():
+    crs = CRS("EPSG:4326")
+    with patch("pyproj.crs.crs.CRS._crs") as crs_mock, pytest.warns(
+        FutureWarning, match="CRS cannot be converted to a PROJ JSON string"
+    ):
+        crs_mock.to_json.return_value = None
+        assert crs.to_json() is None
+
+
 def test_to_proj4_enum():
     crs = CRS.from_epsg(4326)
     with pytest.warns(UserWarning):
@@ -1063,11 +1135,12 @@ def test_coordinate_operation_equals():
 
 
 @pytest.mark.parametrize(
-    "input_str", ["urn:ogc:def:coordinateOperation:EPSG::1671", RGF93toWSG84]
+    "input_str",
+    ["urn:ogc:def:coordinateOperation:EPSG::1671", "RGF93 v1 to WGS 84 (1)"],
 )
 def test_coordinate_operation__from_string(input_str):
     co = CoordinateOperation.from_string(input_str)
-    assert co.name == RGF93toWSG84
+    assert co.name == "RGF93 v1 to WGS 84 (1)"
 
 
 def test_coordinate_operation__from_name():
