@@ -18,7 +18,7 @@ from pyproj.crs.coordinate_operation import (
     VerticalPerspectiveConversion,
 )
 from pyproj.exceptions import CRSError
-from test.conftest import PROJ_LOOSE_VERSION
+from test.conftest import PROJ_GTE_901, PROJ_LOOSE_VERSION
 
 
 def _to_dict(operation):
@@ -81,6 +81,14 @@ def test_to_cf_transverse_mercator():
         towgs84="-122.74,-34.27,-22.83,-1.884,-3.400,-3.030,-15.62",
     )
     towgs84_test = [-122.74, -34.27, -22.83, -1.884, -3.4, -3.03, -15.62]
+    horizontal_datum_name = (
+        "Unknown based on International 1924 (Hayford 1909, 1910) ellipsoid"
+    )
+    if PROJ_GTE_901:
+        horizontal_datum_name = (
+            f"{horizontal_datum_name} using "
+            "towgs84=-122.74,-34.27,-22.83,-1.884,-3.400,-3.030,-15.62"
+        )
     expected_cf = {
         "semi_major_axis": 6378388.0,
         "semi_minor_axis": crs.ellipsoid.semi_minor_metre,
@@ -88,9 +96,7 @@ def test_to_cf_transverse_mercator():
         "reference_ellipsoid_name": "International 1924 (Hayford 1909, 1910)",
         "longitude_of_prime_meridian": 0.0,
         "prime_meridian_name": "Greenwich",
-        "horizontal_datum_name": (
-            "Unknown based on International 1924 (Hayford 1909, 1910) ellipsoid"
-        ),
+        "horizontal_datum_name": horizontal_datum_name,
         "towgs84": towgs84_test,
         "grid_mapping_name": "transverse_mercator",
         "latitude_of_projection_origin": 0.0,
@@ -473,6 +479,43 @@ def test_rotated_pole_to_cf():
     _test_roundtrip(expected_cf, "GEOGCRS[")
 
 
+def test_grib_rotated_pole_to_cf():
+    rotated_pole_wkt = """GEOGCRS["Coordinate System imported from GRIB file",
+        BASEGEOGCRS["Coordinate System imported from GRIB file",
+            DATUM["unnamed",
+                ELLIPSOID["Sphere",6371229,0,
+                    LENGTHUNIT["metre",1,
+                        ID["EPSG",9001]]]],
+            PRIMEM["Greenwich",0,
+                ANGLEUNIT["degree",0.0174532925199433,
+                    ID["EPSG",9122]]]],
+        DERIVINGCONVERSION["Pole rotation (GRIB convention)",
+            METHOD["Pole rotation (GRIB convention)"],
+            PARAMETER["Latitude of the southern pole (GRIB convention)",-33.443381,
+                ANGLEUNIT["degree",0.0174532925199433,
+                    ID["EPSG",9122]]],
+            PARAMETER["Longitude of the southern pole (GRIB convention)",-93.536426,
+                ANGLEUNIT["degree",0.0174532925199433,
+                    ID["EPSG",9122]]],
+            PARAMETER["Axis rotation (GRIB convention)",0,
+                ANGLEUNIT["degree",0.0174532925199433,
+                    ID["EPSG",9122]]]],
+        CS[ellipsoidal,2],
+            AXIS["latitude",north,
+                ORDER[1],
+                ANGLEUNIT["degree",0.0174532925199433,
+                    ID["EPSG",9122]]],
+            AXIS["longitude",east,
+                ORDER[2],
+                ANGLEUNIT["degree",0.0174532925199433,
+                    ID["EPSG",9122]]]]"""
+    crs = CRS(rotated_pole_wkt)
+    with pytest.warns(UserWarning):
+        cf_dict = crs.to_cf(errcheck=True)
+    assert cf_dict.pop("crs_wkt").startswith("GEOGCRS[")
+    assert not cf_dict
+
+
 def test_cf_lambert_conformal_conic_1sp():
     crs = CRS.from_cf(
         dict(
@@ -742,15 +785,13 @@ def test_geos_crs_sweep():
 
 
 def test_geos_crs_fixed_angle_axis():
-    with pytest.warns(DeprecationWarning):
-        crs = CRS.from_cf(
-            dict(
-                grid_mapping_name="geostationary",
-                perspective_point_height=1,
-                fixed_angle_axis="y",
-            ),
-            errcheck=True,
-        )
+    crs = CRS.from_cf(
+        dict(
+            grid_mapping_name="geostationary",
+            perspective_point_height=1,
+            fixed_angle_axis="y",
+        ),
+    )
     expected_cf = {
         "semi_major_axis": 6378137.0,
         "semi_minor_axis": crs.ellipsoid.semi_minor_metre,
@@ -1261,7 +1302,7 @@ def test_lambert_cylindrical_equal_area():
 
 
 def test_mercator_a():
-    crs = ProjectedCRS(conversion=MercatorAConversion(1, 2, 3, 4))
+    crs = ProjectedCRS(conversion=MercatorAConversion(0, 2, 3, 4))
     expected_cf = {
         "semi_major_axis": 6378137.0,
         "semi_minor_axis": crs.ellipsoid.semi_minor_metre,
@@ -1271,7 +1312,7 @@ def test_mercator_a():
         "prime_meridian_name": "Greenwich",
         "horizontal_datum_name": "World Geodetic System 1984",
         "grid_mapping_name": "mercator",
-        "standard_parallel": 1.0,
+        "standard_parallel": 0.0,
         "longitude_of_projection_origin": 2.0,
         "false_easting": 3.0,
         "false_northing": 4.0,
