@@ -31,7 +31,6 @@ from pyproj.crs.coordinate_operation import (
     VerticalPerspectiveConversion,
 )
 from pyproj.exceptions import CRSError
-from test.conftest import PROJ_GTE_82
 
 
 def _to_dict(operation):
@@ -314,7 +313,7 @@ def test_mercator_a_operation__defaults():
 
 def test_mercator_a_operation():
     aeaop = MercatorAConversion(
-        latitude_natural_origin=1,
+        latitude_natural_origin=0,
         longitude_natural_origin=2,
         false_easting=3,
         false_northing=4,
@@ -323,7 +322,7 @@ def test_mercator_a_operation():
     assert aeaop.name == "unknown"
     assert aeaop.method_name == "Mercator (variant A)"
     assert _to_dict(aeaop) == {
-        "Latitude of natural origin": 1.0,
+        "Latitude of natural origin": 0.0,
         "Longitude of natural origin": 2.0,
         "False easting": 3.0,
         "False northing": 4.0,
@@ -331,6 +330,11 @@ def test_mercator_a_operation():
     }
 
 
+def test_mercator_a_operation__invalid_lat0():
+    with pytest.raises(CRSError):
+        MercatorAConversion(latitude_natural_origin=1)
+
+
 def test_mercator_b_operation__defaults():
     lceaop = MercatorBConversion()
     assert lceaop.name == "unknown"
@@ -646,22 +650,13 @@ def test_pole_rotation_netcdf_cf_convention__defaults():
     poleop = PoleRotationNetCDFCFConversion(
         grid_north_pole_latitude=1, grid_north_pole_longitude=2
     )
-    if PROJ_GTE_82:
-        assert poleop.name == "Pole rotation (netCDF CF convention)"
-        assert poleop.method_name == "Pole rotation (netCDF CF convention)"
-        assert _to_dict(poleop) == {
-            "Grid north pole latitude (netCDF CF convention)": 1.0,
-            "Grid north pole longitude (netCDF CF convention)": 2.0,
-            "North pole grid longitude (netCDF CF convention)": 0.0,
-        }
-    else:
-        assert poleop.name == "unknown"
-        assert poleop.method_name == "PROJ ob_tran o_proj=longlat"
-        assert _to_dict(poleop) == {
-            "o_lat_p": 1.0,
-            "o_lon_p": 0.0,
-            "lon_0": 182.0,
-        }
+    assert poleop.name == "Pole rotation (netCDF CF convention)"
+    assert poleop.method_name == "Pole rotation (netCDF CF convention)"
+    assert _to_dict(poleop) == {
+        "Grid north pole latitude (netCDF CF convention)": 1.0,
+        "Grid north pole longitude (netCDF CF convention)": 2.0,
+        "North pole grid longitude (netCDF CF convention)": 0.0,
+    }
 
 
 def test_pole_rotation_netcdf_cf_convention():
@@ -670,22 +665,13 @@ def test_pole_rotation_netcdf_cf_convention():
         grid_north_pole_longitude=2,
         north_pole_grid_longitude=10,
     )
-    if PROJ_GTE_82:
-        assert poleop.name == "Pole rotation (netCDF CF convention)"
-        assert poleop.method_name == "Pole rotation (netCDF CF convention)"
-        assert _to_dict(poleop) == {
-            "Grid north pole latitude (netCDF CF convention)": 1.0,
-            "Grid north pole longitude (netCDF CF convention)": 2.0,
-            "North pole grid longitude (netCDF CF convention)": 10.0,
-        }
-    else:
-        assert poleop.name == "unknown"
-        assert poleop.method_name == "PROJ ob_tran o_proj=longlat"
-        assert _to_dict(poleop) == {
-            "o_lat_p": 1.0,
-            "o_lon_p": 10.0,
-            "lon_0": 182.0,
-        }
+    assert poleop.name == "Pole rotation (netCDF CF convention)"
+    assert poleop.method_name == "Pole rotation (netCDF CF convention)"
+    assert _to_dict(poleop) == {
+        "Grid north pole latitude (netCDF CF convention)": 1.0,
+        "Grid north pole longitude (netCDF CF convention)": 2.0,
+        "North pole grid longitude (netCDF CF convention)": 10.0,
+    }
 
 
 def test_lambert_cylindrical_equal_area_scale_operation__defaults():
